package com.mcwl.web.controller.memberCenter;

import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.domain.entity.SysUser;
import com.mcwl.memberCenter.domain.MemberConsume;
import com.mcwl.memberCenter.domain.Member;
import com.mcwl.memberCenter.domain.MemberLevel;
import com.mcwl.memberCenter.service.MemberBenefitService;
import com.mcwl.memberCenter.service.MemberLevelService;
import com.mcwl.web.controller.memberCenter.pojo.dto.RechargePointsDto;
import com.mcwl.web.controller.memberCenter.pojo.dto.UserMemberDto;
import com.mcwl.memberCenter.service.MemberConsumeService;
import com.mcwl.memberCenter.service.MemberService;
import com.mcwl.system.service.ISysUserService;
import com.mcwl.web.controller.memberCenter.pojo.vo.PointsVO;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("member")
@RequiredArgsConstructor
public class MemberController {

    private final MemberService memberService;

    private final ISysUserService sysUserService;

    private final MemberConsumeService memberConsumeService;

    private final MemberBenefitService memberBenefitService;


    /**
     * 创建用户会员
     *
     * @param userMemberDto 参数
     * @return 用户会员
     */
    @PostMapping("createMember")
    public AjaxResult createMemberCenter(@RequestBody UserMemberDto userMemberDto) {
        Long userId = userMemberDto.getUserId();
        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }
        Long memberLevelId = userMemberDto.getMemberLevelId();
        if (memberLevelId == null) {
            return AjaxResult.warn("会员等级未选择");
        }
        String paymentMethod = userMemberDto.getPaymentMethod();
        if (paymentMethod == null) {
            return AjaxResult.warn("支付方式错误，请重新支付");
        }
        Member member = memberService.createUserMember(userId, memberLevelId, paymentMethod);
        if (member == null) {
            return AjaxResult.warn("创建会员失败");
        }
        return AjaxResult.success(member);
    }


    /**
     * 获取积分余额和历史记录
     * @param userId 用户id
     * @return 积分余额和历史记录
     */
    @GetMapping("getPoints/{id}")
    public AjaxResult getPoints(@PathVariable("id") Long userId) {
        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }

        SysUser sysUser = sysUserService.selectUserById(userId);
        if (sysUser == null) {
            return AjaxResult.warn("用户不存在");
        }

        Member member = memberService.getUseUserMemberByUserId(userId);
        if (member == null) {
            return AjaxResult.warn("用户未开通会员");
        }

        PointsVO pointsVO = new PointsVO();

        // 会员消费记录
        List<MemberConsume> memberConsumeList = memberConsumeService
                .lambdaQuery()
                .eq(MemberConsume::getUserId, userId)
                .list();

        pointsVO.setPoints(member.getPoints());
        pointsVO.setMemberConsumeList(memberConsumeList);

        return AjaxResult.success(pointsVO);
    }


    /**
     * 会员积分充值
     */
    @PostMapping("rechargePoints")
    public AjaxResult rechargePoints(@RequestBody RechargePointsDto rechargePointsDto) {
        Long userId = rechargePointsDto.getUserId();
        Double points = rechargePointsDto.getPoints();

        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }

        SysUser sysUser = sysUserService.selectUserById(userId);
        if (sysUser == null) {
            return AjaxResult.warn("用户不存在");
        }

        if (points == null) {
            return AjaxResult.warn("充值积分为空");
        }

        if (points <= 0) {
            return AjaxResult.warn("充值积分必须大于0");
        }

        Member member = memberService.rechargePoints(userId, points);

        // 返回充值积分
        if (member == null) {
            return AjaxResult.warn("充值积分失败");
        }

        rechargePointsDto.setPoints(member.getPoints());

        return AjaxResult.success(rechargePointsDto);
    }


}
